summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteprefs.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteprefs.h')
-rw-r--r--kopete/libkopete/kopeteprefs.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/libkopete/kopeteprefs.h b/kopete/libkopete/kopeteprefs.h
index 230da46a..83988b73 100644
--- a/kopete/libkopete/kopeteprefs.h
+++ b/kopete/libkopete/kopeteprefs.h
@@ -24,7 +24,7 @@
#include "kopete_export.h"
-class KConfig;
+class TDEConfig;
class KOPETE_EXPORT KopetePrefs : public TQObject
{
@@ -43,14 +43,14 @@ public:
static KopetePrefs *prefs();
/**
* Reads all pref-variables from KConfig
* usually you don't need this as KopetePrefs loads settings
* when an instance is created
*/
void load();
/**
* Stores all pref-variables into KConfig
*/
void save();
@@ -237,7 +237,7 @@ private:
*/
static KopetePrefs *s_prefs;
- KConfig *config;
+ TDEConfig *config;
TQString mIconTheme;
bool mUseEmoticons;
@@ -43,14 +43,14 @@ public:
static KopetePrefs *prefs();
/**
- * Reads all pref-variables from KConfig
+ * Reads all pref-variables from TDEConfig
* usually you don't need this as KopetePrefs loads settings
* when an instance is created
@@ -43,14 +43,14 @@ public:
void load();
/**
- * Stores all pref-variables into KConfig
+ * Stores all pref-variables into TDEConfig
*/
void save();